==============================
Migrating from ``formulation``
==============================

As of release 0.2.0 sniplates has equivalent functionality to formulation.

The field widget templates from formulation are almost 100% compatible, except
for the following cases:

#. Replace ``use`` with ``widget``

